@@ -447,7 +447,12 @@ def sys_cmd(cmd):
         os.system('clear')
     elif cmd == 'sh':
         print('Executing system shell')
-        os.system(os.getenv('SHELL', 'sh'))
+        sh_cmd = os.getenv('SHELL')
+        if sh_cmd is None:
+            sh_cmd = distutils.spawn.find_executable('bash')
+            if not sh_cmd:
+                sh_cmd = 'sh'
+        os.system(sh_cmd)
     else:
         os.system(cmd)
 
