@@ -301,7 +301,7 @@ def get_node_svc_info():
 
 def get_arch():
     import platform
-    return platform.processor()
+    return platform.machine()
 
 
 def safe_download(url, manifest=None, timeout=None, public_key=None, **kwargs):
@@ -321,7 +321,6 @@ def safe_download(url, manifest=None, timeout=None, public_key=None, **kwargs):
             data = manifest['content'][url.rsplit('/', 1)[-1]]
             size = data['size']
             sha256 = data['sha256']
-            signature = data['signature']
         except KeyError:
             raise RuntimeError(f'Info for {url} not found in manifest')
         if len(r.content) != size:
@@ -329,18 +328,4 @@ def safe_download(url, manifest=None, timeout=None, public_key=None, **kwargs):
         import hashlib
         if hashlib.sha256(r.content).hexdigest() != sha256:
             raise RuntimeError(f'Checksum error for {url}')
-        if public_key:
-            import pyaltt2.crypto
-            try:
-                pyaltt2.crypto.verify_signature(r.content, signature,
-                                                public_key)
-            except:
-                raise RuntimeError(f'Signature error for {url}')
     return r.content
-
-
-def get_public_key():
-    if common.public_key is None:
-        with open(f'{common.dir_eva}/share/eva.key') as fh:
-            common.public_key = fh.read()
-    return common.public_key
